@@ -20,6 +20,7 @@
 
 #include <fx.h>
 
+#include "xfedefs.h"
 #include "icons.h"
 #include "MessageBox.h"
 #include "CommandWindow.h"
@@ -104,7 +105,7 @@ void CommandWindow::create()
     // Set text font
     FXString fontspec;
 
-    fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", "Helvetica,100,normal,regular");
+    fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", DEFAULT_TEXT_FONT);
     if (!fontspec.empty())
     {
         FXFont* font = new FXFont(getApp(), fontspec);
