@@ -442,7 +442,7 @@ DirPanel::DirPanel(FXWindow* owner, FXComposite* p, FXColor listbackcolor, FXCol
     FXPacker*        packer = new FXHorizontalFrame(cont, LAYOUT_LEFT|JUSTIFY_LEFT|LAYOUT_FILL_X|FRAME_NONE, 0, 0, 0, 0, 0, 0, 0, 0);
 
     // Visually indicate if the panel is active
-    activeicon = new FXLabel(packer, "", greenbuttonicon, JUSTIFY_LEFT|LAYOUT_LEFT);
+    activeicon = new FXButton(packer, "", greenbuttonicon, this, DirPanel::ID_FILELIST, BUTTON_TOOLBAR|JUSTIFY_LEFT|LAYOUT_LEFT);
 
     // Panel title
     paneltitle = new TextLabel(packer, 0, this, ID_FILELIST, LAYOUT_FILL_X|LAYOUT_FILL_Y);
@@ -550,7 +550,7 @@ void DirPanel::setActive()
 {
     // Set active icon
     activeicon->setIcon(greenbuttonicon);
-    activeicon->setTipText(_("Panel has focus"));
+    activeicon->setTipText(_("Panel is active"));
     list->setFocus();
     isactive = true;
 
@@ -565,7 +565,7 @@ void DirPanel::setInactive()
 {
     // Set active icon
     activeicon->setIcon(graybuttonicon);
-    activeicon->setTipText(_("Panel does not have focus"));
+    activeicon->setTipText(_("Activate panel"));
     isactive = false;
 }
 
@@ -2691,13 +2691,13 @@ long DirPanel::onCmdMount(FXObject*, FXSelector sel, void*)
     {
         op = MOUNT;
         msg = _("Mount");
-        cmd = "mount ";
+	    cmd = getApp()->reg().readStringEntry("PROGS", "mount", DEFAULT_MOUNTCMD) + FXString(" ");
     }
     else
     {
         op = UNMOUNT;
         msg = _("Unmount");
-        cmd = "umount ";
+		cmd = getApp()->reg().readStringEntry("PROGS", "unmount", DEFAULT_UMOUNTCMD) + FXString(" ");
     }
     cmd += ::quote(dir);
     cmd += " 2>&1";
