@@ -18,7 +18,7 @@ protected:
     DirList*           list;
     FXPacker*          statusbar;
     FXLabel*           status;
-    FXLabel*           activeicon;
+    FXButton*          activeicon;
     FXString           trashlocation;
     FXString           trashfileslocation;
     FXString           trashinfolocation;
