@@ -37,7 +37,7 @@ protected:
     FXLabel*               statuslabel;
     FXLabel*               filterlabel;
     FXHorizontalSeparator* panelsep;
-    FXLabel*               activeicon;
+    FXButton*               activeicon;
     FXString               name;
     FXbool                 ctrlkey;
     FXbool                 selmult;
