@@ -150,7 +150,7 @@ FontSelector::FontSelector(FXComposite* p, FXObject* tgt, FXSelector sel, FXuint
     preview = new FXLabel(scroll, "ABCDEFGHIJKLMNOPQRSTUVWXYZ\nabcdefghijklmnopqrstuvwxyz\n0123456789", NULL, JUSTIFY_CENTER_X|JUSTIFY_CENTER_Y);
     preview->setBackColor(getApp()->getBackColor());
 
-    strlcpy(selected.face, "helvetica", sizeof(selected.face)+1);
+    strlcpy(selected.face, "Helvetica", sizeof(selected.face)+1);
     selected.size = 90;
     selected.weight = FXFont::Bold;
     selected.slant = 0;
