@@ -14,6 +14,12 @@ enum OverwriteBoxReturn
     OVWBOX_CLICKED_SKIP_ALL     = 4,
 };
 
+// Dialog type
+enum OverwriteBoxType
+{
+    OVWBOX_MULTIPLE_FILES = 0,
+    OVWBOX_SINGLE_FILE    = 1,
+};
 
 // Message box
 class FXAPI OverwriteBox : public DialogBox
@@ -25,20 +31,22 @@ protected:
     OverwriteBox(const OverwriteBox&)
     {}
 public:
-    long onCmdClicked(FXObject*,FXSelector,void*);
+    long onCmdClicked(FXObject*, FXSelector, void*);
 public:
-    enum{
+    enum
+    {
         ID_CLICKED_CANCEL=DialogBox::ID_LAST,
-		ID_CLICKED_OVERWRITE,
+        ID_CLICKED_OVERWRITE,
         ID_CLICKED_OVERWRITE_ALL,
         ID_CLICKED_SKIP,
         ID_CLICKED_SKIP_ALL,
         ID_LAST
     };
 public:
-    OverwriteBox(FXWindow *win,const FXString& name,const FXString& text,FXuint opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0);
-	OverwriteBox(FXWindow *win,const FXString& name,const FXString& text, FXString& srcsize, FXString& srcmtime, FXString& tgtsize, 
-	             FXString& tgtmtime,FXuint opts=DECOR_TITLE|DECOR_BORDER,int x=0,int y=0);
+    OverwriteBox(FXWindow* win, const FXString& name, const FXString& text, FXuint type = OVWBOX_MULTIPLE_FILES, FXuint opts = DECOR_TITLE|DECOR_BORDER, int x = 0, int y = 0);
+
+    OverwriteBox(FXWindow* win, const FXString& name, const FXString& text, FXString& srcsize, FXString& srcmtime, FXString& tgtsize,
+                 FXString& tgtmtime, FXuint type = OVWBOX_MULTIPLE_FILES, FXuint opts = DECOR_TITLE|DECOR_BORDER, int x = 0, int y = 0);
 
 };
 
