@@ -93,6 +93,8 @@ FXDEFMAP(PreferencesBox) PreferencesMap[] =
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_BROWSE_VIDEOPLAY, PreferencesBox::onCmdBrowse),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_BROWSE_AUDIOPLAY, PreferencesBox::onCmdBrowse),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_BROWSE_XTERM, PreferencesBox::onCmdBrowse),
+    FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_BROWSE_MOUNTCMD, PreferencesBox::onCmdBrowse),
+    FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_BROWSE_UMOUNTCMD, PreferencesBox::onCmdBrowse),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_COLOR, PreferencesBox::onCmdColor),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_NORMALFONT, PreferencesBox::onCmdNormalFont),
     FXMAPFUNC(SEL_COMMAND, PreferencesBox::ID_TEXTFONT, PreferencesBox::onCmdTextFont),
@@ -323,7 +325,7 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     folder_warning = new FXCheckButton(group, _("Warn when setting current folder in search window"));
 #if defined(linux)
     mount = new FXCheckButton(group, _("Warn when mount points are not responding"));
-    show_mount = new FXCheckButton(group, _("Display mount/umount success messages"));
+    show_mount = new FXCheckButton(group, _("Display mount / unmount success messages"));
 #endif
     preserve_date_warning = new FXCheckButton(group, _("Warn when date preservation failed"));
     root_warning = new FXCheckButton(group, _("Warn if running as root"));
@@ -434,6 +436,22 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     oldxterm = getApp()->reg().readStringEntry("PROGS", "xterm", DEFAULT_TERMINAL);
     xterm->setText(oldxterm);
 
+    group = new FXGroupBox(programs, _("Volume management"), GROUPBOX_TITLE_LEFT|FRAME_GROOVE|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+    matrix = new FXMatrix(group, 3, MATRIX_BY_COLUMNS|LAYOUT_SIDE_TOP|LAYOUT_FILL_X|LAYOUT_FILL_Y);
+
+    new FXLabel(matrix, _("Mount:"), NULL, JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    mountcmd = new FXTextField(matrix, 30, NULL, 0, FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
+    new FXButton(matrix, _("\tSelect file..."), filedialogicon, this, ID_BROWSE_MOUNTCMD, FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
+    oldmountcmd = getApp()->reg().readStringEntry("PROGS", "mount", DEFAULT_MOUNTCMD);
+    mountcmd->setText(oldmountcmd);
+
+    new FXLabel(matrix, _("Unmount:"), NULL, JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
+    umountcmd = new FXTextField(matrix, 30, NULL, 0, FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
+    new FXButton(matrix, _("\tSelect file..."), filedialogicon, this, ID_BROWSE_UMOUNTCMD, FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y, 0, 0, 0, 0, 20, 20);
+    oldumountcmd = getApp()->reg().readStringEntry("PROGS", "unmount", DEFAULT_UMOUNTCMD);
+    umountcmd->setText(oldumountcmd);
+
+
     // Fourth tab - Visual
     new FXTabItem(tabbook, _("&Themes"), NULL);
     FXVerticalFrame* visual = new FXVerticalFrame(tabbook, FRAME_RAISED);
@@ -491,13 +509,13 @@ PreferencesBox::PreferencesBox(FXWindow* win, FXColor listbackcolor, FXColor lis
     new FXLabel(fmatrix, _("Normal font:"), NULL, JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     normalfont = new FXTextField(fmatrix, 30, NULL, 0, FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
     new FXButton(fmatrix, _(" Select..."), NULL, this, ID_NORMALFONT, FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y); //,0,0,0,0,20,20);
-    oldnormalfont = getApp()->reg().readStringEntry("SETTINGS", "font", "Helvetica,100,normal,regular");
+    oldnormalfont = getApp()->reg().readStringEntry("SETTINGS", "font", DEFAULT_NORMAL_FONT);
     normalfont->setText(oldnormalfont);
 
     new FXLabel(fmatrix, _("Text font:"), NULL, JUSTIFY_LEFT|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW);
     textfont = new FXTextField(fmatrix, 30, NULL, 0, FRAME_THICK|FRAME_SUNKEN|LAYOUT_FILL_COLUMN|LAYOUT_FILL_ROW|LAYOUT_FILL_X);
     new FXButton(fmatrix, _(" Select..."), NULL, this, ID_TEXTFONT, FRAME_RAISED|FRAME_THICK|LAYOUT_RIGHT|LAYOUT_CENTER_Y); //0,0,0,0,20,20);
-    oldtextfont = getApp()->reg().readStringEntry("SETTINGS", "textfont", "Helvetica,100,normal,regular");
+    oldtextfont = getApp()->reg().readStringEntry("SETTINGS", "textfont", DEFAULT_TEXT_FONT);
     textfont->setText(oldtextfont);
 
     // Sixth tab - Key bindings
@@ -659,6 +677,14 @@ long PreferencesBox::onCmdBrowse(FXObject* o, FXSelector s, void* p)
         case ID_BROWSE_XTERM:
             xterm->setText(FXPath::name(path));
             break;
+
+        case ID_BROWSE_MOUNTCMD:
+            mountcmd->setText(FXPath::name(path));
+            break;
+
+        case ID_BROWSE_UMOUNTCMD:
+            umountcmd->setText(FXPath::name(path));
+            break;
         }
     }
     return(1);
@@ -672,7 +698,7 @@ long PreferencesBox::onCmdNormalFont(FXObject*, FXSelector, void*)
     FXFontDesc fontdesc;
     FXString   fontspec;
 
-    fontspec = getApp()->reg().readStringEntry("SETTINGS", "font", "Helvetica,100,normal,regular");
+    fontspec = getApp()->reg().readStringEntry("SETTINGS", "font", DEFAULT_NORMAL_FONT);
     FXFont* nfont = new FXFont(getApp(), fontspec);
     nfont->create();
     nfont->getFontDesc(fontdesc);
@@ -696,7 +722,7 @@ long PreferencesBox::onCmdTextFont(FXObject*, FXSelector, void*)
     FXFontDesc fontdesc;
     FXString   fontspec;
 
-    fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", "Helvetica,100,normal,regular");
+    fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", DEFAULT_TEXT_FONT);
     FXFont* tfont = new FXFont(getApp(), fontspec);
     tfont->create();
     tfont->getFontDesc(fontdesc);
@@ -1627,6 +1653,19 @@ long PreferencesBox::onCmdAccept(FXObject* o, FXSelector s, void* p)
         getApp()->reg().writeStringEntry("PROGS", "xterm", xterm->getText().text());
     }
 
+    // Mount command has changed
+    if (oldmountcmd != mountcmd->getText())
+    {
+        getApp()->reg().writeStringEntry("PROGS", "mount", mountcmd->getText().text());
+    }
+
+    // Unmount command has changed
+    if (oldumountcmd != umountcmd->getText())
+    {
+        getApp()->reg().writeStringEntry("PROGS", "unmount", umountcmd->getText().text());
+    }
+
+
     getApp()->reg().writeUnsignedEntry("OPTIONS", "auto_save_layout", autosave->getCheck());
     getApp()->reg().writeUnsignedEntry("SETTINGS", "save_win_pos", savewinpos->getCheck());
     getApp()->reg().writeUnsignedEntry("OPTIONS", "use_trash_can", trashcan->getCheck());
@@ -1891,6 +1930,8 @@ long PreferencesBox::onCmdCancel(FXObject* o, FXSelector s, void* p)
     audioplayer->setText(oldaudioplayer);
     videoplayer->setText(oldvideoplayer);
     xterm->setText(oldxterm);
+    mountcmd->setText(oldmountcmd);
+    umountcmd->setText(oldumountcmd);
 
     // Fourth tab - Visual
     themesList->setCurrentItem(themelist_prev);
@@ -1962,6 +2003,8 @@ FXuint PreferencesBox::execute(FXuint placement)
     oldaudioplayer = audioplayer->getText();
     oldvideoplayer = videoplayer->getText();
     oldxterm = xterm->getText();
+    oldmountcmd = mountcmd->getText();
+    oldumountcmd = umountcmd->getText();
 
     // Fourth tab - Visual
     themelist_prev = themesList->getCurrentItem();
