@@ -68,6 +68,8 @@ private:
     FXTextField*   audioplayer;
     FXTextField*   normalfont;
     FXTextField*   textfont;
+    FXTextField*   mountcmd;
+    FXTextField*   umountcmd;
     FXString       oldiconpath;
     FXString       oldtxtviewer;
     FXString       oldtxteditor;
@@ -82,6 +84,8 @@ private:
     FXString       oldpdfviewer;
     FXString       oldaudioplayer;
     FXString       oldvideoplayer;
+    FXString       oldmountcmd;
+    FXString       oldumountcmd;
     FXCheckButton* autosave;
     FXCheckButton* savewinpos;
     FXCheckButton* diropen;
@@ -201,6 +205,8 @@ public:
         ID_BROWSE_VIDEOPLAY,
         ID_BROWSE_AUDIOPLAY,
         ID_BROWSE_XTERM,
+        ID_BROWSE_MOUNTCMD,
+        ID_BROWSE_UMOUNTCMD,
         ID_COLOR,
         ID_NORMALFONT,
         ID_TEXTFONT,
