@@ -1169,10 +1169,12 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o, FXSelector s, void* p)
 
 	FXbool confirm = false;
 	
+#ifdef STARTUP_NOTIFICATION
 	if (executable && snbutton->getCheck() != sndisable_prev)
 	{
 		confirm = true;
 	}
+#endif
 	
     FXbool cond;
     if (edit) // Condition is not the same if edit exist or not
@@ -1191,7 +1193,6 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o, FXSelector s, void* p)
 		confirm = true;
 	}
 
-
     // Source and target path names
     FXString targetpath;
     FXString sourcepath = parentdir+"/"+source;
@@ -1212,19 +1213,16 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o, FXSelector s, void* p)
 		confirm = true;
 	}
 
-
     if ((oldgrp != perm->grp->getText()) || (oldusr != perm->user->getText()) || perm->rec->getCheck())
     {
 		confirm = true;
 	}
 
-
     if (!perm->own->getCheck() && ((mode != orig_mode) || perm->rec->getCheck()))
     {
 		confirm = true;
 	}
 
-
     FXbool confirm_properties = getApp()->reg().readUnsignedEntry("OPTIONS", "confirm_properties", true);
 
 	if (confirm == true && confirm_properties == true)
@@ -1584,11 +1582,11 @@ long PropertiesBox::onCmdAcceptSingle(FXObject* o, FXSelector s, void* p)
         delete f;
     }
 
-     DialogBox::onCmdAccept(o, s, p);
+	DialogBox::onCmdAccept(o, s, p);
 
 	// Redraw file lists
     ((XFileExplorer*)mainWindow)->deselectAll();
-    ((XFileExplorer*)mainWindow)->redrawPanels();
+    ((XFileExplorer*)mainWindow)->refreshPanels();
 
 	// Delete object
 	delete this;
@@ -1797,7 +1795,7 @@ long PropertiesBox::onCmdAcceptMult(FXObject* o, FXSelector s, void* p)
 
     // Redraw the file lists
     ((XFileExplorer*)mainWindow)->deselectAll();
-    ((XFileExplorer*)mainWindow)->redrawPanels();
+    ((XFileExplorer*)mainWindow)->refreshPanels();
 	
 	delete[]files;
 	delete[]paths;
@@ -1826,10 +1824,6 @@ long PropertiesBox::onCmdCancel(FXObject* o, FXSelector s, void* p)
 
     DialogBox::onCmdCancel(o, s, p);
 
-    // Redraw the file lists
-    ((XFileExplorer*)mainWindow)->redrawPanels();
-
-
 	delete this;
 
     return(1);
@@ -2018,9 +2012,10 @@ long PropertiesBox::onWatchProcess(FXObject*, FXSelector, void*)
     char size[256];
     int nread;
 
+
 	FXString strbuf, hsize;
 	FXString dsize, subdirs, files;
-	FXuint nbsubdirs, nbfiles;
+	FXuint nbsubdirs=0, nbfiles;
 	FXulong dirsize;
 
     if ((waitpid(pid, NULL, WNOHANG) == 0))
@@ -2041,34 +2036,38 @@ long PropertiesBox::onWatchProcess(FXObject*, FXSelector, void*)
                     buf[nread] = '\0';
 
                     // Get last string between two slashes
+                    // or before the slash if there is only one
                     strbuf = buf;
 					strbuf = strbuf.rbefore('/');
-
 					if (strbuf.rfind('/') >= 0)
 					{
 						strbuf=strbuf.rafter('/');
-						
-						dsize = strbuf.section(' ',0);
-						files = strbuf.section(' ',1);
-						subdirs = strbuf.section(' ',2);
+					}
+					
+					dsize = strbuf.section(' ',0);
+					files = strbuf.section(' ',1);
+					subdirs = strbuf.section(' ',2);
 
-						hsize = ::hSize((char*)dsize.text());
+					hsize = ::hSize((char*)dsize.text());
 
-						// Directory size, number of files, number of sub directories
-						dirsize = FXULongVal(dsize);
-						nbfiles = FXUIntVal(files);
-						nbsubdirs = FXUIntVal(subdirs);
+					// Directory size, number of files, number of sub directories
+					dirsize = FXULongVal(dsize);
+					nbfiles = FXUIntVal(files);
+					nbsubdirs = FXUIntVal(subdirs);
+					if (nbsubdirs > 0)
+					{
+						nbsubdirs--;
+					}
 
 #if __WORDSIZE == 64
-						snprintf(size,sizeof(size)-1,_("%s (%lu bytes)"),hsize.text(),dirsize);        
+					snprintf(size,sizeof(size)-1,_("%s (%lu bytes)"),hsize.text(),dirsize);        
 #else
-						snprintf(size,sizeof(size)-1,_("%s (%llu bytes)"),hsize.text(),dirsize);        
-#endif
-						fileSize->setText(size);
+					snprintf(size,sizeof(size)-1,_("%s (%llu bytes)"),hsize.text(),dirsize);        
+#endif	
+					fileSize->setText(size);
 
-						snprintf(size, sizeof(size)-1, _("%u files, %u subfolders"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);
-						fileSizeDetails->setText(size);
-					}
+					snprintf(size, sizeof(size)-1, _("%u files, %u subfolders"), nbfiles-nbsubdirs-nbseldirs, nbsubdirs);
+					fileSizeDetails->setText(size);
 
 					if (nread < (int)(sizeof(buf)-1))
 					{
@@ -2086,7 +2085,7 @@ long PropertiesBox::onWatchProcess(FXObject*, FXSelector, void*)
         while ((nread = read(pipes[0], buf, sizeof(buf)-1)) > 0)
         {
 			buf[nread] = '\0';
-			
+
 			// Get last string between two slashes
 			strbuf = buf;
 			strbuf = strbuf.rbefore('/');
@@ -2105,6 +2104,10 @@ long PropertiesBox::onWatchProcess(FXObject*, FXSelector, void*)
 				dirsize = FXULongVal(dsize);
 				nbfiles = FXUIntVal(files);
 				nbsubdirs = FXUIntVal(subdirs);
+				if (nbsubdirs >0)
+				{
+					nbsubdirs--;
+				}
 
 #if __WORDSIZE == 64
 				snprintf(size,sizeof(size)-1,_("%s (%lu bytes)"),hsize.text(),dirsize);        
@@ -2125,7 +2128,7 @@ long PropertiesBox::onWatchProcess(FXObject*, FXSelector, void*)
 
         // Close pipes
         ::close(pipes[0]);
-        ::close(pipes[1]);
+        ::close(pipes[1]);   
     }
 
     return(1);
@@ -2170,7 +2173,11 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o, FXSelector s, void* p)
 				}
 				if (pid == 0) // Child
 				{
-					nbsubdirs--;
+					if (nbsubdirs > 0)
+					{
+						nbsubdirs--;
+					}
+					
 					pathsize(buf, &nbfiles, &nbsubdirs, &dirsize, pipes);
 
 					_exit(EXIT_SUCCESS);
@@ -2235,7 +2242,12 @@ long PropertiesBox::onUpdSizeAndPerm(FXObject* o, FXSelector s, void* p)
 					if (isDirectory)
 					{
 						strlcpy(buf, pathname.text(), pathname.length()+1);
-						totalnbsubdirs--;
+						
+						if (totalnbsubdirs > 0)
+						{
+							totalnbsubdirs--;
+						}
+						
 						pathsize(buf, &totalnbfiles, &totalnbsubdirs, &totaldirsize, pipes);
 					}
 					else // Regular file
