@@ -481,7 +481,7 @@ SearchWindow::SearchWindow(FXApp* app, const FXString& name, FXuint opts, int x,
 
     // Set text font for the warning window
     FXString fontspec;
-    fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", "Helvetica,100,normal,regular");
+    fontspec = getApp()->reg().readStringEntry("SETTINGS", "textfont", DEFAULT_TEXT_FONT);
     if (!fontspec.empty())
     {
         FXFont* font = new FXFont(getApp(), fontspec);
