@@ -414,7 +414,7 @@ long XFilePackage::onCmdQuit(FXObject*, FXSelector, void*)
     saveConfig();
 
     // Exit
-    getApp()->exit(EXIT_FAILURE);
+    getApp()->exit(EXIT_SUCCESS);
     return(1);
 }
 
@@ -586,7 +586,7 @@ void XFilePackage::create()
 
     // Set Xfp text font according to the Xfe registry
     FXString fontspec;
-    fontspec = reg_xfe->readStringEntry("SETTINGS", "textfont", "Helvetica,100,normal,regular");
+    fontspec = reg_xfe->readStringEntry("SETTINGS", "textfont", DEFAULT_TEXT_FONT);
     if (!fontspec.empty())
     {
         FXFont* font = new FXFont(getApp(), fontspec);
@@ -749,7 +749,7 @@ int main(int argc, char* argv[])
 
     // Set Xfp normal font according to the Xfe registry
     FXString fontspec;
-    fontspec = reg_xfe->readStringEntry("SETTINGS", "font", "Helvetica,100,normal,regular");
+    fontspec = reg_xfe->readStringEntry("SETTINGS", "font", DEFAULT_NORMAL_FONT);
     if (!fontspec.empty())
     {
         FXFont* normalFont = new FXFont(application, fontspec);
@@ -817,7 +817,7 @@ int main(int argc, char* argv[])
     if ((dpkg == false) && (rpm == false))
     {
         MessageBox::error(window, BOX_OK, _("Error"), _("No compatible package manager (rpm or dpkg) found!"));
-        exit(EXIT_SUCCESS);
+        exit(EXIT_FAILURE);
     }
 
     // Start
