@@ -1,10 +1,10 @@
 #ifndef HELP_H
 #define HELP_H
-  
+
 #include "config.h"
 #include "i18n.h"
 
-#define HELP_TEXT _("\n \
+#define HELP_TEXT    _("\n \
 \n \
 \n \
                                   XFE, X File Explorer File Manager\n \
@@ -55,6 +55,7 @@
     - Natural sort order (foo10.txt comes after foo2.txt...)\n \
     - Copy/Cut/Paste files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
     - Drag and Drop files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
+    - Disk usage command \n \
     - Root mode with authentication by su or sudo\n \
     - Status line\n \
     - File associations\n \
@@ -69,7 +70,7 @@
     - Bookmarks\n \
     - Back and forward history lists for folder navigation\n \
     - Color themes (GNOME, KDE, Windows...)\n \
-    - Icon themes (Xfe, GNOME, KDE, XFCE, Tango, Windows...)\n \
+    - Icon themes (Xfe, GNOME, KDE, Tango, Windows...)\n \
     - Control themes (Standard or Clearlooks like)\n \
     - Create archives (tar, compress, zip, gzip, bzip2, xz and 7zip formats are supported)\n \
     - File comparison (through external tool)\n \
@@ -103,7 +104,7 @@
     * Cut to clipboard                   - Ctrl-X\n \
     * Deselect all                       - Ctrl-Z\n \
     * Display help                       - F1\n \
-    * Create new file                    - F2\n \
+    * Create new file                    - Ctrl-N\n \
     * Create new folder                  - F7\n \
     * Big icon list                      - F10\n \
     * Small icon list                    - F11\n \
@@ -127,7 +128,7 @@
     * Switch panels                     - Ctrl-K\n \
     * Clear location bar                - Ctrl-L\n \
     * Mount file system (Linux only)    - Ctrl-M\n \
-    * Rename file                       - Ctrl-N\n \
+    * Rename file                       - F2\n \
     * Refresh panels                    - Ctrl-R\n \
     * Symlink files to location         - Ctrl-S\n \
     * Launch terminal                   - Ctrl-T\n \
@@ -183,7 +184,8 @@
 \n \
     * Ctrl-+ and Ctrl--                 - zoom in and zoom out image in Xfi\n \
     * Shift-F10                         - display context menus in Xfe\n \
-    * Return, Space                     - enter folders in file lists, open files, select button actions, etc.\n \
+    * Space                             - select an item in file list\n \
+    * Return                            - enter folders in file lists, open files, select button actions, etc.\n \
     * Esc                               - close current dialog, unselect files, etc.\n \
 \n \
 \n \
@@ -370,7 +372,7 @@
  Many thanks to Maxim Baranov for his excellent X Win Commander and to all people that have provided useful\n \
  patches, translations, tests and advices.\n \
 \n \
- [Last revision: 11/01/2015]\n \
+ [Last revision: 28/11/2015]\n \
 \n \
  ")
 ;
