@@ -437,7 +437,7 @@ int main(int argc, char* argv[])
 
     // Set normal font
     FXString fontspec;
-    fontspec = application->reg().readStringEntry("SETTINGS", "font", "Helvetica,100,normal,regular");
+    fontspec = application->reg().readStringEntry("SETTINGS", "font", DEFAULT_NORMAL_FONT);
     if (!fontspec.empty())
     {
         FXFont* normalFont = new FXFont(application, fontspec);
