@@ -48,14 +48,12 @@ void startup_completed(void)
 // Hack to obtain a timestamp for startup notification
 // Create a fake window and set up a property change event
 // Code snippet borrowed from the Internet
-Time gettimestamp(void)
+Time gettimestamp(Display *display)
 {
-    Display* display;
     Window   window;
     XEvent   event;
     Atom     atom_name, atom_type;
 
-    display = XOpenDisplay(0);
     window = XCreateWindow(display, DefaultRootWindow(display), 0, 0, 1, 1, 0, 0, InputOnly, 0, 0, NULL);
     XSelectInput(display, window, PropertyChangeMask);
     atom_name = XInternAtom(display, "_NET_WM_USER_TIME_WINDOW", False);
@@ -63,7 +61,6 @@ Time gettimestamp(void)
     XChangeProperty(display, window, atom_name, atom_type, 8, PropModeReplace, (const FXuchar*)&window, 1);
     XNextEvent(display, &event);
     assert(event.type == PropertyNotify);
-    XCloseDisplay(display);
 
     return(((XPropertyEvent*)&event)->time);
 }
@@ -154,7 +151,7 @@ int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbo
         sn_launcher_context_set_binary_name(context, cmdname.text());
         sn_launcher_context_set_description(context, message.text());
         sn_launcher_context_set_icon_name(context, cmdname.text());
-        timestamp = gettimestamp();
+        timestamp = gettimestamp(xdisplay);
         sn_launcher_context_initiate(context, "Xfe", cmd.text(), timestamp);
 
         // Run command in background
@@ -174,6 +171,7 @@ int runcmd(FXString cmd, FXString cmdname, FXString dir, FXString startdir, FXbo
             break;
         }
         sn_launcher_context_unref(context);
+        XCloseDisplay(xdisplay);
     }
 
     // Run command without startup notification
