@@ -1,7 +1,17 @@
 // Common Xfe constants
 
 #ifndef COPYRIGHT
-#define COPYRIGHT    "Copyright (C) 2002-2015 Roland Baudin (roland65@free.fr)"
+#define COPYRIGHT    "Copyright (C) 2002-2016 Roland Baudin (roland65@free.fr)"
+#endif
+
+// Default normal font
+#ifndef DEFAULT_NORMAL_FONT
+#define DEFAULT_NORMAL_FONT    "Helvetica,100,normal,regular"
+#endif
+
+// Default text font
+#ifndef DEFAULT_TEXT_FONT
+#define DEFAULT_TEXT_FONT    "Courier,100,normal,regular"
 #endif
 
 // Default file and directory list time format
@@ -160,13 +170,13 @@
 #define DEFAULTICONPATH    "~/.config/xfe/icons/xfe-theme:/usr/local/share/xfe/icons/xfe-theme:/usr/share/xfe/icons/xfe-theme"
 #endif
 
-// Command to launch Xfe as root with sudo or su, using Xvt as a terminal
+// Command to launch Xfe as root with sudo or su, using st as a terminal
 #ifndef SUDOCMD
-#define SUDOCMD    "-fn 7x14 -geometry 60x4 -e sudo su -c 'nohup xfe >& /dev/null & sleep 1'"
+#define SUDOCMD    " -g 60x4 -e sudo su -c 'nohup xfe >& /dev/null & sleep 1'"
 #endif
 
 #ifndef SUCMD
-#define SUCMD    "-fn 7x14 -geometry 60x4 -e su -c 'nohup xfe >& /dev/null & sleep 1'"
+#define SUCMD    " -g 60x4 -e su -c 'nohup xfe >& /dev/null & sleep 1'"
 #endif
 
 // Tooltips setup time and duration
@@ -237,6 +247,16 @@
 #define DEFAULT_VIDEOPLAYER    "mplayer"
 #endif
 
+// Default mount command
+#ifndef DEFAULT_MOUNTCMD
+#define DEFAULT_MOUNTCMD    "mount"
+#endif
+
+// Default unmount command
+#ifndef DEFAULT_UMOUNTCMD
+#define DEFAULT_UMOUNTCMD   "umount"
+#endif
+
 
 // FOX hacks
 
